@@ -2,7 +2,7 @@
 
 #
 # Fsdb::IO::Writer.pm
-# $Id$
+# $Id: fd415a455a6624afba5caf36461747a81c2d0186 $
 #
 # Copyright (C) 2005-2013 by John Heidemann <johnh@isi.edu>
 #
@@ -372,7 +372,7 @@ sub write_row {
 
 =head2 write_row_from_href
 
-    $fsdb->write_row_from_aref(\%h);
+    $fsdb->write_row_from_href(\%h);
 
 Write out %h, a hash of the row fields where each key is a field name.
 
